def ask_for(message, default, ask_type=int):
    while True:
        try:
            x = input(message + f" [default = {default}] ")
            x = default if x == "" else x
            x = ask_type(x)
            break
        except ValueError:
            print(f"'{x}' ain't '{ask_type.__name__}'. Provide correct value.")
    return x


def ask_if(message, false="n"):
    while True:
        x = input(message + f" [default = Y] ")
        if x in ("Y","n",""):
            break
        else:
            print("wrong answer: let us try again:")
    return x != "n"



# This Python file uses the following encoding: utf-8
from setuptools import setup, find_packages

setup(  name='nogui',
        packages=find_packages(),
        version='0.0.1',
        description='A simple set of functions to communicate with the users via terminal rather than gui.',
        long_description='A simple set of functions to communicate with the users via terminal rather than gui.',
        author='MatteoLacki',
        author_email='matteo.lacki@gmail.com',
        url='https://github.com/MatteoLacki/nogui.git',
        keywords=['terminal gui', 'cli forms'],
        classifiers=['Development Status :: 1 - Planning',
                     'Programming Language :: Python :: 3.6',
                     'Programming Language :: Python :: 3.7']
)
